OC.L10N.register(
    "text",
    {
    "File not found" : "Файл олдсонгүй",
    "Guest" : "Зочин",
    "you" : "та",
    "edit" : "Засварлах",
    "Saved" : "Хадгалах",
    "Link" : "Холбоос",
    "Undo" : "буцах",
    "Cancel" : "Цуцлах",
    "URL" : "URL",
    "Save" : "Хадгалах",
    "Translate" : "Орчуулга",
    "to" : "Дуусах нь",
    "Replace" : "Солих",
    "Upload" : "байршуулах",
    "Edit" : "засварлах",
    "Source code" : "эх үүсвэр талын код",
    "Details" : "Дэлгэрэнгүй",
    "Choose" : "Сонгох"
},
"nplurals=2; plural=(n != 1);");
